package com.ruoyi.project.business.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.project.business.domain.TqContract;
import com.ruoyi.project.business.domain.bo.TqContractBo;
import com.ruoyi.project.business.domain.vo.contract.TqContractDto;
import com.ruoyi.project.business.domain.vo.contract.TqContractVo;
import com.ruoyi.project.business.dto.ContractSigningStatistic;

/**
 * 合同列表Service接口
 * 
 * @author ruoyi
 * @date 2024-08-13
 */
public interface ITqContractService 
{
    /**
     * 查询合同列表
     * 
     * @param id 合同列表主键
     * @return 合同列表
     */
    public TqContract selectTqContractById(Long id);
    public TqContractVo getContractById(Long id);

    /**
     * 查询合同列表列表
     * 
     * @param tqContract 合同列表
     * @return 合同列表集合
     */
    public List<TqContract> selectTqContractList(TqContract tqContract);

    public List<TqContractVo> selectTqContractBoList(TqContractBo tqContract);
    public List<TqContractVo> selectTqContractBoListApp(TqContractBo tqContract);
    /**
     * 新增合同列表
     * 
     * @param tqContractDto 合同列表
     * @return 结果
     */
    public int insertTqContract(TqContractDto tqContractDto);



    /**
     * 修改合同列表
     * 
     * @param tqContractDto 合同列表
     * @return 结果
     */
    public int updateTqContract(TqContractDto tqContractDto);



    /**
     * 批量删除合同列表
     * 
     * @param ids 需要删除的合同列表主键集合
     * @return 结果
     */
    public int deleteTqContractByIds(Long[] ids);

    /**
     * 删除合同列表信息
     * 
     * @param id 合同列表主键
     * @return 结果
     */
    public int deleteTqContractById(Long id);

    void exportContract(Long id);

    ContractSigningStatistic contractSigningStatistic(TqContractDto params);
}
